@@ -1,6 +1,6 @@
 /*
-Copyright (C) 2007-208, Thomas Treichl <treichl@users.sourceforge.net>
-OdePkg - Package for solving ordinary differential equations with this software
+Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -248,7 +248,7 @@ DEFUN_DLD (odebda, args, nargout,
 @deftypefnx {Command} {[@var{sol}] =} odebda (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 @deftypefnx {Command} {[@var{t}, @var{y}, [@var{xe}, @var{ye}, @var{ie}]] =} odebda (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 \n\
-This function file can be used to solve a set of non--stiff or stiff ordinary differential equations (ODEs) and non--stiff or stiff differential algebraic equations (DAEs). This function file is a wrapper file that uses Jeff Cash's Fortran solver @file{mebdfdae.f}.\n\
+This function file can be used to solve a set of stiff ordinary differential equations (ODEs) and stiff differential algebraic equations (DAEs). This function file is a wrapper file that uses Jeff Cash's Fortran solver @file{mebdfdae.f}.\n\
 \n\
 If this function is called with no return argument then plot the solution over time in a figure window while solving the set of ODEs that are defined in a function and specified by the function handle @var{@@fun}. The second input argument @var{slot} is a double vector that defines the time slot, @var{init} is a double vector that defines the initial values of the states, @var{opt} can optionally be a structure array that keeps the options created with the command @command{odeset} and @var{par1}, @var{par2}, @dots{} can optionally be other input arguments of any type that have to be passed to the function defined by @var{@@fun}.\n\
 \n\
@@ -551,11 +551,11 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   octave_idx_type IDID = 1;
   octave_idx_type LOUT = 6; // Logical output channel "not opened"
   octave_idx_type LWORK = 42*N+3*N*N+4;
-  double WORK[LWORK];
+  OCTAVE_LOCAL_BUFFER (double, WORK, LWORK);
   for (octave_idx_type vcnt = 0; vcnt < LWORK; vcnt++)
     WORK[vcnt] = 0.0;
   octave_idx_type LIWORK = N+14;
-  octave_idx_type IWORK[LIWORK];
+  OCTAVE_LOCAL_BUFFER (octave_idx_type, IWORK, LIWORK);
   for (octave_idx_type vcnt = 0; vcnt < LIWORK; vcnt++)
     IWORK[vcnt] = 0;
   octave_idx_type MBND[4] = {N, N, N, N};
@@ -855,11 +855,11 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %!test %# RelTol and NormControl option -- higher accuracy
 %!  vopt = odeset ('RelTol', 1e-8, 'NormControl', 'on');
 %!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
-%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-6);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-5);
 %!test %# Keeps initial values while integrating
 %!  vopt = odeset ('NonNegative', 2);
 %!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
-%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-6);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-5);
 %!test %# Details of OutputSel and Refine can't be tested
 %!  vopt = odeset ('OutputFcn', @fout, 'OutputSel', 1, 'Refine', 5);
 %!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
