@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
-OdePkg - Package for solving ordinary differential equations with this software
+OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ typedef octave_idx_type (*odepkg_radau5_soltype)
 extern "C" {
   F77_RET_T F77_FUNC (radau5, RADAU5)
     (const octave_idx_type& N, odepkg_radau5_usrtype,
-     const octave_idx_type& X, const double* Y, const double& XEND,
+     const double& X, const double* Y, const double& XEND,
      const double& H, const double* RTOL, const double* ATOL,
      const octave_idx_type& ITOL, odepkg_radau5_jactype, const octave_idx_type& IJAC,
      const octave_idx_type& MLJAC, const octave_idx_type& MUJAC, odepkg_radau5_masstype,
@@ -101,8 +101,8 @@ octave_idx_type odepkg_radau5_usrfcn
   ColumnVector A(N);
   for (octave_idx_type vcnt = 0; vcnt < N; vcnt++) {
     A(vcnt) = Y[vcnt];
-    //    octave_stdout << "bin hier Y[" << vcnt << "] " << Y[vcnt] << std::endl;
-    //    octave_stdout << "bin hier T " << X << std::endl;
+    //    octave_stdout << "I am here Y[" << vcnt << "] " << Y[vcnt] << std::endl;
+    //    octave_stdout << "I am here T " << X << std::endl;
   }
 
   // Fill the variable for the input arguments before evaluating the
@@ -133,7 +133,6 @@ octave_idx_type odepkg_radau5_jacfcn
   ColumnVector A(N);
   for (octave_idx_type vcnt = 0; vcnt < N; vcnt++)
     A(vcnt) = Y[vcnt];
-  // octave_stdout << "bin drinne" << std::endl;
 
   // Set the values that are needed as input arguments before calling
   // the Jacobian function and then call the Jacobian interface
@@ -252,7 +251,7 @@ DEFUN_DLD (ode5r, args, nargout,
 @deftypefnx {Command} {[@var{sol}] =} ode5r (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 @deftypefnx {Command} {[@var{t}, @var{y}, [@var{xe}, @var{ye}, @var{ie}]] =} ode5r (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 \n\
-This function file can be used to solve a set of non--stiff or stiff ordinary differential equations (ODEs) and non--stiff or stiff differential algebraic equations (DAEs). This function file is a wrapper to Hairer's and Wanner's Fortran solver @file{radau5.f}.\n\
+This function file can be used to solve a set of stiff ordinary differential equations (ODEs) and stiff differential algebraic equations (DAEs). This function file is a wrapper to Hairer's and Wanner's Fortran solver @file{radau5.f}.\n\
 \n\
 If this function is called with no return argument then plot the solution over time in a figure window while solving the set of ODEs that are defined in a function and specified by the function handle @var{@@fun}. The second input argument @var{slot} is a double vector that defines the time slot, @var{init} is a double vector that defines the initial values of the states, @var{opt} can optionally be a structure array that keeps the options created with the command @command{odeset} and @var{par1}, @var{par2}, @dots{} can optionally be other input arguments of any type that have to be passed to the function defined by @var{@@fun}.\n\
 \n\
@@ -564,10 +563,10 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   octave_idx_type MUMAS=N;
   octave_idx_type IOUT = 1; // The SOLOUT function will always be called
   octave_idx_type LWORK = N*(N+N+7*N+3*7+3)+20;
-  double WORK[LWORK];
+  OCTAVE_LOCAL_BUFFER (double, WORK, LWORK);
   for (octave_idx_type vcnt = 0; vcnt < LWORK; vcnt++) WORK[vcnt] = 0.0;
   octave_idx_type LIWORK = (2+(7-1)/2)*N+20;
-  octave_idx_type IWORK[LIWORK];
+  OCTAVE_LOCAL_BUFFER (octave_idx_type, IWORK, LIWORK);
   for (octave_idx_type vcnt = 0; vcnt < LIWORK; vcnt++) IWORK[vcnt] = 0;
   double RPAR[1] = {0.0};
   octave_idx_type IPAR[1] = {0};
@@ -587,6 +586,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   if (!vradau5evefun.is_empty ())
     odepkg_auxiliary_evaleventfun (vradau5evefun, vtim, args(2), vradau5extarg, 0);
 
+  // octave_stdout <<  "X VALUE=" << X << XEND << std::endl;
   // We are calling the core solver and solve the set of ODEs or DAEs
   F77_XFCN (radau5, RADAU5, // Keep 5 arguments per line here
             (N, odepkg_radau5_usrfcn, X, Y,
